@@ -16,13 +16,11 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include "common/darktable.h"
 #include "common/debug.h"
 #include "common/history.h"
 #include "common/styles.h"
+#include "common/utility.h"
 #include "control/control.h"
 #include "develop/imageop.h"
 #include "gui/gtk.h"
@@ -224,7 +222,7 @@ static void _gui_styles_new_style_response(GtkDialog *dialog,
     if(newname && *newname)
     {
       /* show prompt dialog when style already exists */
-      if(g->newname && (dt_styles_exists(newname)) != 0)
+      if(newname && (dt_styles_exists(newname)) != 0)
       {
         /* on button yes delete style name for overwriting */
         if(dt_gui_show_yes_no_dialog
@@ -527,8 +525,7 @@ static void _gui_styles_dialog_run(gboolean edit,
   if(name && (dt_styles_exists(name)) == 0) return;
 
   /* initialize the dialog */
-  dt_gui_styles_dialog_t *sd =
-    (dt_gui_styles_dialog_t *)g_malloc0(sizeof(dt_gui_styles_dialog_t));
+  dt_gui_styles_dialog_t *sd = g_malloc0(sizeof(dt_gui_styles_dialog_t));
 
   sd->nameorig = g_strdup(name);
   sd->imgid = imgid;
@@ -771,7 +768,7 @@ static void _gui_styles_dialog_run(gboolean edit,
     {
       for(const GList *items_iter = items; items_iter; items_iter = g_list_next(items_iter))
       {
-        dt_style_item_t *item = (dt_style_item_t *)items_iter->data;
+        dt_style_item_t *item = items_iter->data;
         const dt_develop_mask_mode_t mask_mode = item->blendop_params->mask_mode;
 
         if(item->num != -1 && item->selimg_num != -1) // defined in style and image
@@ -826,7 +823,7 @@ static void _gui_styles_dialog_run(gboolean edit,
     {
       for(const GList *items_iter = items; items_iter; items_iter = g_list_next(items_iter))
       {
-        dt_history_item_t *item = (dt_history_item_t *)items_iter->data;
+        dt_history_item_t *item = items_iter->data;
 
         /* lookup history item module */
         gboolean enabled = TRUE;
@@ -965,7 +962,9 @@ GtkWidget *dt_gui_style_content_dialog(char *name, const dt_imgid_t imgid)
 #define STYLE_TOOLTIP_MAX_WIDTH 30
 
   // Style name
-  gchar *esc_name = g_markup_printf_escaped("<b>%s</b>", name);
+  char *localized_name = dt_util_localize_segmented_name(name, TRUE);
+  gchar *esc_name = g_markup_printf_escaped("<b>%s</b>", localized_name);
+  free(localized_name);
   label = gtk_label_new(NULL);
   gtk_label_set_markup(GTK_LABEL(label), esc_name);
   gtk_label_set_max_width_chars(GTK_LABEL(label), STYLE_TOOLTIP_MAX_WIDTH);
@@ -976,13 +975,15 @@ GtkWidget *dt_gui_style_content_dialog(char *name, const dt_imgid_t imgid)
   // Style description, it can be empty
   char *des = dt_styles_get_description(name);
 
-  if(strlen(des) > 0)
+  if(des && strlen(des) > 0)
   {
+    char *localized_des = dt_util_localize_segmented_name(des, TRUE);
     // If the name and/or description are long and become multi-line, it will look
     // hard to understand what is what, so we add a horizontal separator between them.
     gtk_box_pack_start(GTK_BOX(ht), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), TRUE, TRUE, 0);
 
-    gchar *esc_des = g_markup_printf_escaped("<b>%s</b>", des);
+    gchar *esc_des = g_markup_printf_escaped("<b>%s</b>", localized_des);
+    g_free(localized_des);
     label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(label), esc_des);
     gtk_label_set_max_width_chars(GTK_LABEL(label), STYLE_TOOLTIP_MAX_WIDTH);
@@ -998,11 +999,14 @@ GtkWidget *dt_gui_style_content_dialog(char *name, const dt_imgid_t imgid)
   while(l)
   {
     char mn[64];
-    dt_style_item_t *i = (dt_style_item_t *)l->data;
+    dt_style_item_t *i = l->data;
 
     if(i->multi_name && strlen(i->multi_name) > 0)
     {
-      snprintf(mn, sizeof(mn), "(%s)", i->multi_name);
+      snprintf(mn, sizeof(mn), "(%s)",
+               i->multi_name_hand_edited
+               ? i->multi_name
+               : dt_util_localize_segmented_name(i->multi_name, TRUE));
     }
     else
     {
