@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2015-2024 darktable developers.
+    Copyright (C) 2015-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,9 +15,6 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include "common/interpolation.h"
 #include "common/opencl.h"
 #include "common/imagebuf.h"
@@ -115,8 +112,8 @@ void modify_roi_in(dt_iop_module_t *self,
   }
 }
 
-void tiling_callback(struct dt_iop_module_t *self,
-                     struct dt_dev_pixelpipe_iop_t *piece,
+void tiling_callback(dt_iop_module_t *self,
+                     dt_dev_pixelpipe_iop_t *piece,
                      const dt_iop_roi_t *roi_in,
                      const dt_iop_roi_t *roi_out,
                      struct dt_develop_tiling_t *tiling)
@@ -136,20 +133,19 @@ void tiling_callback(struct dt_iop_module_t *self,
   tiling->yalign = 1;
 }
 
-void distort_mask(struct dt_iop_module_t *self,
-                  struct dt_dev_pixelpipe_iop_t *piece,
+void distort_mask(dt_iop_module_t *self,
+                  dt_dev_pixelpipe_iop_t *piece,
                   const float *const in,
                   float *const out,
                   const dt_iop_roi_t *const roi_in,
                   const dt_iop_roi_t *const roi_out)
 {
-  const struct dt_interpolation *itor =
-    dt_interpolation_new(DT_INTERPOLATION_USERPREF);
+  const dt_interpolation_t *itor = dt_interpolation_new(DT_INTERPOLATION_USERPREF);
   dt_interpolation_resample_1c(itor, out, roi_out, in, roi_in);
 }
 
 #ifdef HAVE_OPENCL
-int process_cl(struct dt_iop_module_t *self,
+int process_cl(dt_iop_module_t *self,
                dt_dev_pixelpipe_iop_t *piece,
                cl_mem dev_in, cl_mem dev_out,
                const dt_iop_roi_t *const roi_in,
@@ -158,7 +154,7 @@ int process_cl(struct dt_iop_module_t *self,
   if(roi_out->scale > 1.0f) // trust cl code for 1:1 copy here or downscale
   {
     dt_print(DT_DEBUG_OPENCL,
-             "[opencl_finalscale] upscaling not yet supported by opencl code\n");
+             "[opencl_finalscale] upscaling not yet supported by opencl code");
     return DT_OPENCL_PROCESS_CL;
   }
 
@@ -167,7 +163,7 @@ int process_cl(struct dt_iop_module_t *self,
 
   dt_print_pipe(DT_DEBUG_IMAGEIO,
                 exporting ? "clip_and_zoom_roi" : "clip_and_zoom",
-                piece->pipe, self, piece->pipe->devid, roi_in, roi_out, "device=%i\n", devid);
+                piece->pipe, self, piece->pipe->devid, roi_in, roi_out, "device=%i", devid);
   if(exporting)
     return dt_iop_clip_and_zoom_roi_cl(devid, dev_out, dev_in, roi_out, roi_in);
   else
@@ -185,7 +181,7 @@ void process(dt_iop_module_t *self,
   const gboolean exporting = piece->pipe->type == DT_DEV_PIXELPIPE_EXPORT;
   dt_print_pipe(DT_DEBUG_IMAGEIO,
                 exporting ? "clip_and_zoom_roi" : "clip_and_zoom",
-                piece->pipe, self, DT_DEVICE_CPU, roi_in, roi_out, "\n");
+                piece->pipe, self, DT_DEVICE_CPU, roi_in, roi_out);
 
   if(exporting)
     dt_iop_clip_and_zoom_roi((float *)ovoid, (float *)ivoid, roi_out, roi_in);
@@ -229,14 +225,6 @@ void init(dt_iop_module_t *self)
   self->gui_data = NULL;
 }
 
-void cleanup(dt_iop_module_t *self)
-{
-  free(self->params);
-  self->params = NULL;
-  free(self->default_params);
-  self->default_params = NULL;
-}
-
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
